ENVIRONMENT_TEST_NAME = 'PAGINATE_BY'
ENVIRONMENT_TEST_VALUE = '999999'

TEST_BOOTSTAP_SETTING_NAME = 'TEST_BOOTSTRAP_SETTING'

TEST_CONFIG_FILE_NAME = 'TEST_CONFIG_FILE_NAME'
TEST_CONFIG_FILE_VALUE = 'TEST_CONFIG_FILE_VALUE'
TEST_ENVIRONMENT_VARIABLE_NAME = 'TEST_ENVIRONMENT_VARIABLE_NAME'
TEST_ENVIRONMENT_VALUE = 'TEST_ENVIRONMENT_VALUE'
TEST_GLOBAL_NAME = 'TEST_GLOBAL_NAME'
TEST_GLOBAL_VALUE = 'TEST_GLOBAL_VALUE'

TEST_NAMESPACE_LABEL = 'test namespace label'
TEST_NAMESPACE_NAME = 'test_namespace_name'

TEST_SETTING_GLOBAL_NAME = 'SMART_SETTINGS_TEST_SETTING'
TEST_SETTING_INITIAL_VALUE = 'test_setting_initial_value'
TEST_SETTING_DEFAULT_VALUE = 'test_setting_default_value'
TEST_SETTING_VALUE = 'test_setting_value'
TEST_SETTING_VALUE_OVERRIDE = 'test value override'

TEST_SETTING_VALIDATION_BAD_VALUE = 'test bad value'
TEST_SETTING_VALIDATION_GOOD_VALUE = 'test good value'
